@@ -12,8 +12,6 @@
 
     nom.subject <- as.character(subject)
 
-#### INCLUSION PRIOR
-    nom.prior <- as.character(args$prior)
 ####
     if(!missing(mixture) & ng==1) stop("No mixture can be specified with ng=1")
     if(missing(mixture) & ng>1) stop("The argument mixture has to be specified for ng > 1")
@@ -32,6 +30,7 @@
 
     if(missing(data)){ stop("The argument data should be specified and defined as a data.frame")} 
     if(missing(subject)){ stop("The argument subject must be specified in any model even without random-effects")} 
+    if(!is.numeric(data[,subject])) stop("The argument subject must be numeric")
 ### ad 2/04/2012
     X0.names2 <- c("intercept")
 ### ad
@@ -251,7 +250,7 @@
 #### INCLUSION PRIOR 
     if(missing(prior)){ PRIOR <- seq(0,length=length(IND))} 
     if(!missing(prior)){ 
-        PRIOR <- newdata[,nom.prior]
+        PRIOR <- newdata[,prior]
         PRIOR[(is.na(PRIOR))] <- 0
     }
 ####
