@@ -373,7 +373,7 @@ void F77_SUB(postprob2)(double * Y0,
 			int * indiceY0,
 			double * uniqueY0,
 			int * nvalSPL0,
-			double * epsY0,
+			int * epsY0,
 			int * nbevt0,
 			double * tsurv00,
 			int * idtrunc0,
